@@ -17,7 +17,7 @@ from random import shuffle
 from lollypop.sqlcursor import SqlCursor
 from lollypop.define import App, Type, OrderBy, StorageType, LovedFlags
 from lollypop.logger import Logger
-from lollypop.utils import remove_static, make_subrequest
+from lollypop.utils import remove_static, make_subrequest, noaccents
 
 
 class AlbumsDatabase:
@@ -1040,6 +1040,7 @@ class AlbumsDatabase:
         if orderby == OrderBy.ARTIST_YEAR:
             order = " ORDER BY artists.sortname\
                      COLLATE NOCASE COLLATE LOCALIZED,\
+                     albums.year,\
                      albums.timestamp,\
                      albums.name\
                      COLLATE NOCASE COLLATE LOCALIZED"
@@ -1052,11 +1053,13 @@ class AlbumsDatabase:
             order = " ORDER BY albums.name\
                      COLLATE NOCASE COLLATE LOCALIZED"
         elif orderby == OrderBy.YEAR_DESC:
-            order = " ORDER BY albums.timestamp DESC,\
+            order = " ORDER BY albums.year DESC,\
+                     albums.timestamp DESC,\
                      albums.name\
                      COLLATE NOCASE COLLATE LOCALIZED"
         elif orderby == OrderBy.YEAR_ASC:
-            order = " ORDER BY albums.timestamp ASC,\
+            order = " ORDER BY albums.year ASC,\
+                     albums.timestamp ASC,\
                      albums.name\
                      COLLATE NOCASE COLLATE LOCALIZED"
         else:
@@ -1282,18 +1285,34 @@ class AlbumsDatabase:
             result = sql.execute(request, filters)
             return list(itertools.chain(*result))
 
-    def search(self, searched, storage_type):
+    def search(self, terms, storage_type):
         """
             Search for albums looking like string
-            @param searched as str without accents
+            @param terms array of strings
             @param storage_type as StorageType
             @return album ids as [int]
         """
         with SqlCursor(self.__db) as sql:
-            filters = ("%" + searched + "%", storage_type)
-            request = "SELECT rowid, name FROM albums\
-                       WHERE noaccents(name) LIKE ?\
-                       AND albums.storage_type & ? LIMIT 25"
+            filters = (
+                *["%" + noaccents(term) + "%" for term in terms],
+                storage_type
+            )
+
+            request = \
+                "SELECT\
+                    al.rowid,\
+                    al.name,\
+                    (" + (" + ".join(["(CONCAT(noaccents(al.name), ' ', noaccents(ar.name)) LIKE ?)" for _ in terms])) + ") AS score\
+                FROM albums al\
+                INNER JOIN album_artists aa\
+                ON aa.album_id = al.id\
+                INNER JOIN artists ar\
+                ON ar.id = aa.artist_id\
+                WHERE score > 0\
+                AND al.storage_type & ?\
+                GROUP BY al.rowid\
+                ORDER BY score DESC\
+                LIMIT 25"
             result = sql.execute(request, filters)
             return list(result)
 
