@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2021 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -10,7 +10,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gtk
+from gi.repository import Gtk, GLib
 
 from lollypop.define import App, ViewType, MARGIN, ScanUpdate
 from lollypop.view_tracks_album import AlbumTracksView
@@ -42,26 +42,33 @@ class AlbumView(LazyLoadingView, SignalsHelper):
         self.__grid.set_orientation(Gtk.Orientation.VERTICAL)
         self.__banner = AlbumBannerWidget(self.__album, self.storage_type,
                                           self.view_type)
+        self.__banner.show()
+        self.__banner.populate()
         self.add_widget(self.__grid, self.__banner)
         return [
             (App().scanner, "scan-finished", "_on_scan_finished"),
             (App().scanner, "updated", "_on_collection_updated"),
-            (App().player, "current-changed", "_on_current_changed"),
-            (App().player, "duration-changed", "_on_duration_changed"),
         ]
 
     def populate(self):
         """
             Populate the view with album
         """
-        if self.__tracks_view is None:
-            self.__tracks_view = AlbumTracksView(self.__album, self.view_type)
-            self.__tracks_view.show()
-            self.__tracks_view.connect("populated", self.__on_tracks_populated)
-            self.__tracks_view.set_margin_start(MARGIN)
-            self.__tracks_view.set_margin_end(MARGIN)
-            self.__tracks_view.populate()
-            self.__grid.add(self.__tracks_view)
+        def do():
+            if self.__tracks_view is None:
+                self.__tracks_view = AlbumTracksView(self.__album,
+                                                     self.view_type)
+                self.__tracks_view.show()
+                self.__tracks_view.connect("populated",
+                                           self.__on_tracks_populated)
+                self.__tracks_view.connect("selected",
+                                           self.__on_track_selected)
+                self.__tracks_view.set_margin_start(MARGIN)
+                self.__tracks_view.set_margin_end(MARGIN)
+                self.__tracks_view.populate()
+                self.__grid.add(self.__tracks_view)
+        # Let the banner populate first
+        GLib.idle_add(do)
 
     @property
     def name(self):
@@ -87,8 +94,7 @@ class AlbumView(LazyLoadingView, SignalsHelper):
         """
         return {"album": self.__album,
                 "storage_type": self.storage_type,
-                "view_type": self.view_type & ~(ViewType.ADAPTIVE |
-                                                ViewType.SMALL)}
+                "view_type": self.view_type & ~ViewType.SMALL}
 
     @property
     def filtered(self):
@@ -136,36 +142,6 @@ class AlbumView(LazyLoadingView, SignalsHelper):
         if scan_update == ScanUpdate.REMOVED:
             App().window.container.go_back()
 
-    def _on_current_changed(self, player):
-        """
-            Update children state
-            @param player as Player
-        """
-        if self.__tracks_view is not None:
-            self.__tracks_view.set_playing_indicator()
-
-    def _on_duration_changed(self, player, track_id):
-        """
-            Update track duration
-            @param player as Player
-            @param track_id as int
-        """
-        if self.__tracks_view is not None:
-            self.__tracks_view.update_duration(track_id)
-
-    def _on_adaptive_changed(self, window, status):
-        """
-            Handle adaptive mode for views
-            @param window as Window
-            @param status as bool
-            @return bool
-        """
-        changed = LazyLoadingView._on_adaptive_changed(self, window, status)
-        if changed:
-            self.__banner.set_view_type(self.view_type)
-            self.__tracks_view.set_view_type(self.view_type)
-        return changed
-
 #######################
 # PRIVATE             #
 #######################
@@ -176,7 +152,6 @@ class AlbumView(LazyLoadingView, SignalsHelper):
         """
         if self.__tracks_view.is_populated:
             self.emit("populated")
-            self.__banner.show()
             if self.view_type & ViewType.OVERLAY:
                 from lollypop.view_albums_line import AlbumsArtistLineView
                 for artist_id in self.__album.artist_ids:
@@ -192,4 +167,12 @@ class AlbumView(LazyLoadingView, SignalsHelper):
                     self.__grid.add(others_box)
                     self.__others_boxes.append(others_box)
         else:
-            self.__tracks_view.populate()
+            GLib.idle_add(self.__tracks_view.populate)
+
+    def __on_track_selected(self, view, selected):
+        """
+            Mark banner as filtered
+            @param view as TracksView
+            @param selected as bool
+        """
+        self.__banner.set_selected(selected)
